#!/usr/bin/python

import sys

from charmhelpers.core.hookenv import (
    Hooks,
    UnregisteredHookError,
    log,
)

from charmhelpers.fetch import (
    apt_install,
    apt_update,
    apt_purge,
    configure_sources,
)

from neutron_iovisor_utils import (
    determine_packages,
    load_iovisor,
    remove_iovisor,
    ensure_mtu,
)

hooks = Hooks()


@hooks.hook()
def install():
    configure_sources()
    apt_update()
    pkgs = determine_packages()
    for pkg in pkgs:
        options = ['--force-yes', '--option=Dpkg::Options::=--force-confold']
        apt_install(pkg, options=options, fatal=True)
    load_iovisor()
    ensure_mtu()


@hooks.hook('plumgrid-plugin-relation-joined')
def plumgrid_plugin_joined():
    ensure_mtu()


@hooks.hook('config-changed')
def config_changed():
    configure_sources(update=True)
    #options = ['--force-yes', '--option=Dpkg::Options::=--force-confold']
    #apt_install(filter_installed_packages(determine_packages()),
    #            options=options,
    #            fatal=True)


@hooks.hook('stop')
def stop():
    remove_iovisor()
    pkgs = determine_packages()
    for pkg in pkgs:
        apt_purge(pkg, fatal=False)


def main():
    try:
        hooks.execute(sys.argv)
    except UnregisteredHookError as e:
        log('Unknown hook {} - skipping.'.format(e))


if __name__ == '__main__':
    main()
