
from mock import patch

import neutron_iovisor_utils as nutils

from test_utils import (
    CharmTestCase,
)
import charmhelpers.core.hookenv as hookenv


TO_PATCH = [
    'modprobe',
    'neutron_plugin_attribute',
    'check_call',
    'check_output',
    'set_nic_mtu',
]


def _mock_npa(plugin, attr, net_manager=None):
    plugins = {
        'plumgrid': {
            'config': '/etc/neutron/plugins/plumgrid/plumgrid.ini',
            'driver': 'neutron.plugins.plumgrid.plumgrid_plugin.plumgrid_plugin.NeutronPluginPLUMgridV2',
            'contexts': [],
            'services': [],
            'packages': [['plumgrid-lxc'],
                         ['iovisor-dkms'],
                         ['plumgrid-puppet']],
            'server_packages': ['neutron-server',
                                'neutron-plugin-plumgrid',
                                'plumgrid-pythonlib',
                                'plumgrid-puppet'],
            'server_services': ['neutron-server']
        }
    }
    return plugins[plugin][attr]


class TestNeutronIovisorUtils(CharmTestCase):

    def setUp(self):
        super(TestNeutronIovisorUtils, self).setUp(nutils, TO_PATCH)
        self.neutron_plugin_attribute.side_effect = _mock_npa

    def tearDown(self):
        # Reset cached cache
        hookenv.cache = {}

    def test_determine_packages(self):
        pkg_list = nutils.determine_packages()
        expect = [['plumgrid-lxc'], ['iovisor-dkms'], ['plumgrid-puppet']]
        self.assertItemsEqual(pkg_list, expect)

    def test_load_iovisor(self):
        nutils.load_iovisor()
        self.modprobe.assert_called_with('iovisor')

    def test_remove_iovisor(self):
        nutils.remove_iovisor()
        self.check_call.assert_called_with(['rmmod', 'iovisor'])

    @patch.object(nutils, 'check_output')
    def test_ensure_mtu(self, _check_output):
        _check_output.return_value = 'bridge name\tbridge id\t\tSTP enabled\tinterfaces\njuju-br0\t\t8000.525400b2ef36\tno\t\teth0\n\t\t\t\t\t\t\tveth3VQDMS\n\t\t\t\t\t\t\tveth518T4G\n'
        nutils.ensure_mtu()
